/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/slave/beta-osx64-xr/build/dom/interfaces/svg/nsIDOMSVGAnimateMotionElement.idl
 */

#ifndef __gen_nsIDOMSVGAnimateMotionElement_h__
#define __gen_nsIDOMSVGAnimateMotionElement_h__


#ifndef __gen_nsIDOMSVGAnimationElement_h__
#include "nsIDOMSVGAnimationElement.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDOMSVGAnimateMotionElement */
#define NS_IDOMSVGANIMATEMOTIONELEMENT_IID_STR "8ac8b152-a44f-4456-bda5-b004f8148a93"

#define NS_IDOMSVGANIMATEMOTIONELEMENT_IID \
  {0x8ac8b152, 0xa44f, 0x4456, \
    { 0xbd, 0xa5, 0xb0, 0x04, 0xf8, 0x14, 0x8a, 0x93 }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIDOMSVGAnimateMotionElement : public nsIDOMSVGAnimationElement {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IDOMSVGANIMATEMOTIONELEMENT_IID)

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIDOMSVGAnimateMotionElement, NS_IDOMSVGANIMATEMOTIONELEMENT_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOMSVGANIMATEMOTIONELEMENT \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOMSVGANIMATEMOTIONELEMENT(_to) \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOMSVGANIMATEMOTIONELEMENT(_to) \
  /* no methods! */

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDOMSVGAnimateMotionElement : public nsIDOMSVGAnimateMotionElement
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOMSVGANIMATEMOTIONELEMENT

  nsDOMSVGAnimateMotionElement();

private:
  ~nsDOMSVGAnimateMotionElement();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDOMSVGAnimateMotionElement, nsIDOMSVGAnimateMotionElement)

nsDOMSVGAnimateMotionElement::nsDOMSVGAnimateMotionElement()
{
  /* member initializers and constructor code */
}

nsDOMSVGAnimateMotionElement::~nsDOMSVGAnimateMotionElement()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDOMSVGAnimateMotionElement_h__ */
